@@ -66,12 +66,12 @@ class TrainingConfig:
     This configuration follows the approach described in the research paper,
     with optimized settings for Llama-3.2-3B and BGE-M3 integration.
     """
-    model_id: str = "unsloth/Llama-3.2-3B-Instruct"
+    model_id: str = "convaiinnovations/gemma-finetuned-4b-it"
     embed_model_id: str = "BAAI/bge-m3"
     max_length: int = 512
 
-    # Model architecture dimensions
-    llm_hidden_size: int = 3072  # Llama-3.2-3B hidden size
+    # Model architecture dimensions (auto-detected from model config)
+    llm_hidden_size: int = None  # Auto-detected from model config
     embedding_dim: int = 1024    # BGE-M3 embedding dimension
 
     batch_size: int = 8  # Optimized for Llama-3.2-3B
